// Last sync on 2004-10-20 with help_mp-en.h 1.148
// Translated by:  Carl Frstenberg &#60;azatoth&#64;gmail&#46;com&#62;
// Helped by: Jan Knutar &#60;jknutar&#64;nic&#46;fi&#62;
// ========================= MPlayer hjlp ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char help_text[]=
"Anvndning:   mplayer [argument] [url|skvg/]filnamn\n"
"\n"
"Grundlggande argument: (komplett lista terfinns i `man mplayer`)\n"
" -vo <drv[:enhet]>   vlj video-ut drivrutin & enhet ('-vo help' fr lista)\n"
" -ao <drv[:enhet]>   vlj audio-ut drivrutin & enhet ('-ao help' fr lista)\n"
#ifdef HAVE_VCD
" vcd://<sprnr>      spela (S)VCD (Super Video CD) spr (r enhet, ingen montering)\n"
#endif
#ifdef USE_DVDREAD
" dvd://<titlenr>     spela DVD titel frn enhet istllet fr ifrn en enkel fil\n"
" -alang/-slang       vlj DVD audio/textningssprk (m.h.a. ett 2-teckens landskod)\n"
#endif
" -ss <tidpos>        sk till given position (sekunder eller hh:mm:ss)\n"
" -nosound            spela inte upp ljud\n"
" -fs                 fullskrmsuppspelning (eller -vm, -zoom, detaljer p manualsidan)\n"
" -x <x> -y <y>       stt skrmupplsning (fr anvndning med -vm eller -zoom)\n"
" -sub <fil>          specifiera textningsfil att anvnda (se ocks -subfps, -subdelay)\n"
" -playlist <fil>     specifiera spellistefil\n"
" -vid x -aid y       vlj video (x) och audio (y) strm att spela\n"
" -fps x -srate y     ndra video (x fps) och audio (y Hz) frekvens\n"
" -pp <kvalit>       aktivera postredigeringsfilter (detaljer p manualsidan)\n"
" -framedrop          aktivera reducering av antalet bildrutor (fr lngsamma maskiner)\n" 
"\n"
"Grundlggande navigering: (komplett lista terfinns p manualsidan, ls ven input.conf)\n"
" <-  eller  ->       sk bakt/framt 10 sekunder\n"
" upp eller ner       sk bakt/framt 1 minut\n"
" pgup eller pgdown   sk bakt/framt 10 minuter\n"
" < eller >           stega bakt/framt i spellistan\n"
" p eller SPACE       pausa filmen (tryck p valfri tagent fr att fortstta)\n"
" q eller ESC         stanna spelningen och avsluta programmet\n"
" + eller -           stll in audiofrdrjning med  0.1 sekund\n"
" o                   vxla OSD lge:  ingen / lgesindikator / lgesindikator + tidtagare\n"
" * eller /           ka eller snk PCM-volym\n"
" z eller x           stll in textningsfrdrjning med  0.1 sekund\n"
" r or t              stll in textningsposition upp/ner, se ocks '-vf expand'\n"
"\n"
" * * * LS MANUALEN FR FLER DETALJER, MER AVANCERADE ARGUMENT OCH KOMMANDON * * *\n"
"\n";
#endif

#define MSGTR_SamplesWanted "Fler exempel p detta format behvs fr att vidare ka support. Var vnlig kontakta utvecklarna.\n"

// ========================= MPlayer messages ===========================

// mplayer.c:

#define MSGTR_Exiting "\nStnger ner...\n"
#define MSGTR_ExitingHow "\nStnger ner... (%s)\n"
#define MSGTR_Exit_quit "Avsluta"
#define MSGTR_Exit_eof "Slut p fil"
#define MSGTR_Exit_error "Overkomligt fel"
#define MSGTR_IntBySignal "\nMPlayer var avbruten av signal %d i modul: %s\n"
#define MSGTR_NoHomeDir "Kan inte lokalisera $HOME-katalog.\n"
#define MSGTR_GetpathProblem "get_path(\"config\") problem\n"
#define MSGTR_CreatingCfgFile "Skapar konfigfil: %s\n"
#define MSGTR_CopyCodecsConf "(Kopiera/lnka etc/codecs.conf frn MPlayer's kllkod till ~/.mplayer/codecs.conf)\n"
#define MSGTR_BuiltinCodecsConf "Anvnder standardinbyggd codecs.conf.\n"
#define MSGTR_CantLoadFont "Kan inte ladda font: %s\n"
#define MSGTR_CantLoadSub "Kan inte ladda vald textning: %s\n"
#define MSGTR_DumpSelectedStreamMissing "dump: FATALT: Vald strm ej tillgnglig!\n"
#define MSGTR_CantOpenDumpfile "Kan inte ppna dumpfil.\n"
#define MSGTR_CoreDumped "Core dumpad ;)\n"
#define MSGTR_FPSnotspecified "FPS ej specifierad i filhuvudet eller r icke godknd, anvnd argument -fps.\n"
#define MSGTR_TryForceAudioFmtStr "Frsker att forcera audiocodecfamilj %s...\n"
#define MSGTR_CantFindAudioCodec "Kan inte finna codec fr audioformat 0x%X.\n"
#define MSGTR_RTFMCodecs "Ls DOCS/HTML/en/codecs.html!\n"
#define MSGTR_TryForceVideoFmtStr "Frsker att forcera videocodecfamilj %s...\n"
#define MSGTR_CantFindVideoCodec "Kan inte finna codec fr vald -vo och videoformat 0x%X.\n"
#define MSGTR_CannotInitVO "FATALT: Kan inte initiera videodrivrutin.\n"
#define MSGTR_CannotInitAO "Kan inte ppna/initiera audioenhet -> inget ljud.\n"
#define MSGTR_StartPlaying "Pbrjar uppspelning...\n"

#define MSGTR_SystemTooSlow "\n\n"\
    "           ***********************************************************\n"\
"           **** Ditt system r fr sltt fr att spela upp detta! ****\n"\
"           ***********************************************************\n\n"\
"Troliga orsaker, problem, samt stt att fixa det:\n"\
"- Troligast: trasig/buggig _audio_drivrutin\n"\
"  - Frsk -ao sdl eller anvnd OSS-emulatorn i ALSA.\n"\
"  - Experimentera med olika vrden fr -autosync, 30 r en bra start.\n"\
"- Seg video-ut\n"\
"  - Frsk en annan -vo drivrutin (-vo help fr en lista) eller frsk -framedrop!\n"\
"- Seg CPU\n"\
"  - Frsk att inte spela upp allt fr stora DVD/DivX p en seg CPU! Testa med -hardframedrop.\n"\
"- Trasig fil\n"\
"  - Frsk med olika kombinationer av -nobps -ni -forceidx -mc 0.\n"\
"- Segt media (NFS/SMB mounts, DVD, VCD etc.)\n"\
"  - Frsk med -cache 8192.\n"\
"- Anvnder du -cache till att spela upp en ickeinterleaved AVIfil?\n"\
"  - Frsk -nocache.\n"\
"Ls DOCS/HTML/en/video.html fr optimeringstips.\n"\
"Om inget av dessa hjlper, ls DOCS/HTML/en/bugreports.html.\n\n"

#define MSGTR_NoGui "MPlayer var kompilerad UTAN GUI-support.\n"
#define MSGTR_GuiNeedsX "MPlayer GUI krver X11.\n"
#define MSGTR_Playing "Spelar %s.\n"
#define MSGTR_NoSound "Audio: inget ljud\n"
#define MSGTR_FPSforced "FPS forcerad att vara %5.3f  (ftime: %5.3f).\n"
#define MSGTR_CompiledWithRuntimeDetection "Kompilerad med \"runtime CPU detection\" - VARNING - detta r inte optimalt!\n"\
    "Fr att f bst prestanda, omkompilera med '--disable-runtime-cpudetection'.\n"
#define MSGTR_CompiledWithCPUExtensions "Kompilerad fr x86 med tillgg:"
#define MSGTR_AvailableVideoOutputDrivers "Tillgngliga video-ut-drivrutiner:\n"
#define MSGTR_AvailableAudioOutputDrivers "Tillgngliga audio-ut-drivrutiner:\n"
#define MSGTR_AvailableAudioCodecs "Tillgngliga audiocodec:\n"
#define MSGTR_AvailableVideoCodecs "Tillgngliga videocodec:\n"
#define MSGTR_AvailableAudioFm "Tillgngliga (inkompilerade) audiocodec familjer/drivrutiner:\n"
#define MSGTR_AvailableVideoFm "Tillgngliga (inkompilerade) videocodec familjer/drivrutiner:\n"
#define MSGTR_AvailableFsType "Tillgngliga lgen fr fullskrmslager:\n"
#define MSGTR_UsingRTCTiming "Anvnder Linux's hrdvaru-RTC-tidtagning (%ldHz).\n"
#define MSGTR_CannotReadVideoProperties "Video: Kan inte lsa instllningar.\n"
#define MSGTR_NoStreamFound "Ingen strm funnen.\n"
#define MSGTR_ErrorInitializingVODevice "Fel vid ppning/initiering av vald video_out-enhet (-vo).\n"
#define MSGTR_ForcedVideoCodec "Forcerad videocodec: %s\n"
#define MSGTR_ForcedAudioCodec "Forcerad audiocodec: %s\n"
#define MSGTR_Video_NoVideo "Video: ingen video\n"
#define MSGTR_NotInitializeVOPorVO "\nFATALT: Kunde inte initiera videofilter (-vf) eller video-ut (-vo).\n"
#define MSGTR_Paused "\n  =====  PAUSE  =====\r" // no more than 23 characters (status line for audio files)
#define MSGTR_PlaylistLoadUnable "\nOfrmgen att ladda spellista %s.\n"
#define MSGTR_Exit_SIGILL_RTCpuSel \
    "- MPlayer krachade av en 'Illegal Instruction'.\n"\
"  Det kan vare en bugg i vr nya \"runtime CPU-detection\" kod...\n"\
"  Var god ls DOCS/HTML/en/bugreports.html.\n"
#define MSGTR_Exit_SIGILL \
    "- MPlayer krashade av en 'Illegal Instruction'.\n"\
"  Detta hnder vanligast om du kr koden p en annan CPU n den var\n"\
"  kompilerad/optimerad fr\n"\
"  Verifiera detta!\n"
#define MSGTR_Exit_SIGSEGV_SIGFPE \
    "- MPlayer krashade p grund utav dlig anvndning av CPU/FPU/RAM.\n"\
"  Omkompilera MPlayer med '--enable-debug' och kr en \"'gdb' backtrace\" och\n"\
"  deassemblera. Detaljer terfinns i DOCS/HTML/en/bugreports_what.html#bugreports_crash.\n"
#define MSGTR_Exit_SIGCRASH \
    "- MPlayer krashade. Detta borde inte intrffa.\n"\
"  Det kan vara en bugg i MPlayers kod, eller i din drivrutin, eller i din\n"\
"  gcc version. Om du tror det r MPlayers fel, var vnlig ls\n"\
"  DOCS/HTML/en/bugreports.html och flj instruktionerna dr, Vi kan inte och\n"\
"  kommer inte att hjlpa dig, om du inte kan befodra denna information nr \n"\
"  du rapporterar en trolig bugg.\n"

#define MSGTR_LoadingConfig "Laddar konfiguration '%s'\n"
#define MSGTR_AddedSubtitleFile "SUB: lade till textningsfil %d: %s \n"
#define MSGTR_ErrorOpeningOutputFile "Fel vid ppning av fil [%s] fr skrivning!\n"
#define MSGTR_CommandLine "Kommandorad:"
#define MSGTR_RTCDeviceNotOpenable "Misslyckades att ppna %s: %s (den borde vara lsbar av anvndaren.)\n"
#define MSGTR_LinuxRTCInitErrorIrqpSet "'Linux RTC' initieringsfel i 'ioctl' rtc_irqp_set %lu: %s\n"
#define MSGTR_IncreaseRTCMaxUserFreq "Frsk lgg till \"echo %lu > /proc/sys/dev/rtc/max-user-freq\" till ditt systems uppstartningsscript.\n"
#define MSGTR_LinuxRTCInitErrorPieOn "'Linux RTC init' fel i 'ioctl' [rtc_pie_on]: %s\n"
#define MSGTR_UsingTimingType "Anvnder %s tidtagning.\n"
#define MSGTR_MenuInitialized "Meny initierad: %s\n"
#define MSGTR_MenuInitFailed "Menyinitiering misslyckades.\n"
#define MSGTR_Getch2InitializedTwice "VARNING: getch2_init anropad dubbelt!\n"
#define MSGTR_DumpstreamFdUnavailable "Kan inte dumpa denna strm - ingen 'fd' tillgnglig.\n"
#define MSGTR_FallingBackOnPlaylist "Faller tillbaka med att frska tolka spellista %s...\n"
#define MSGTR_CantOpenLibmenuFilterWithThisRootMenu "Kan inte ppna 'libmenu video filter' med rotmeny %s.\n"
#define MSGTR_AudioFilterChainPreinitError "Fel vid frinitiering av audiofilter!\n"
#define MSGTR_LinuxRTCReadError "'Linux RTC' lsfel: %s\n"
#define MSGTR_SoftsleepUnderflow "Varning! Softsleep underflow!\n"
#define MSGTR_EDLSKIPStartStopLength "\nEDL_SKIP: start [%f], stopp [%f], lngd [%f]\n"
#define MSGTR_MenuCall "Menyanrop\n"
#define MSGTR_EdlCantUseBothModes "Kan inte anvnda -edl och -edlout samtidigt.\n"
#define MSGTR_EdlOutOfMem "Kan inte allokera tillrckligt med minne fr att hlla EDL-data.\n"
#define MSGTR_EdlRecordsNo "Lst %d EDL-funtioner.\n"
#define MSGTR_EdlQueueEmpty "Det r inga EDL-funktioner att ta hand om.\n"
#define MSGTR_EdlCantOpenForWrite "Kan inte ppna EDL-fil [%s] fr skrivning.\n"
#define MSGTR_EdlCantOpenForRead "Kan inte ppna EDL-fil [%s] fr lsning.\n"
#define MSGTR_EdlNOsh_video "Kan inte anvnda EDL utan video, inaktiverar.\n"
#define MSGTR_EdlNOValidLine "Icke godknd EDL-rad: %s\n"
#define MSGTR_EdlBadlyFormattedLine "Dligt formaterad EDL-rad [%d]. Kastar bort.\n"
#define MSGTR_EdlBadLineOverlap "Senaste stopposition var [%f] ; nsta start r [%f]. Noteringar mste vara i kronologisk ordning, kan inte lappa ver. Kastar bort.\n"
#define MSGTR_EdlBadLineBadStop "Stopptid mste vara efter starttid.\n"

#define MSGTR_DvdnavNullEvent "DVDNAV-hndelse NULL?!\n"
#define MSGTR_DvdnavHighlightEventBroken "DVDNAV-hndelse: Highlight-hndelse trasig\n" // FIXME highlight
#define MSGTR_DvdnavEvent "DVDNAV-hndelse Event: %s\n"
#define MSGTR_DvdnavHighlightHide "DVDNAV-hndelse: Highlight gmd\n"
#define MSGTR_DvdnavStillFrame "######################################## DVDNAV-hndelse: Fortfarande bildruta: %d sekunder\n"
#define MSGTR_DvdnavNavStop "DVDNAV-hndelse: Nav Stop\n" // FIXME Nav Stop?
#define MSGTR_DvdnavNavNOP "DVDNAV-hndelse: Nav NOP\n"
#define MSGTR_DvdnavNavSpuStreamChangeVerbose "DVDNAV-hndelse: 'Nav SPU'-strmningsndring: fysisk: %d/%d/%d logisk: %d\n"
#define MSGTR_DvdnavNavSpuStreamChange "DVDNAV-hndelse: 'Nav SPU'-strmningsndring: fysisk: %d logisk: %d\n"
#define MSGTR_DvdnavNavAudioStreamChange "DVDNAV-hndelse: 'Nav Audio'-strmningsndring: fysisk: %d logisk: %d\n"
#define MSGTR_DvdnavNavVTSChange "DVDNAV-hndelse: 'Nav VTS' ndrad\n"
#define MSGTR_DvdnavNavCellChange "DVDNAV-hndelse: 'Nav Cell' ndrad\n"
#define MSGTR_DvdnavNavSpuClutChange "DVDNAV-hndelse: 'Nav SPU CLUT' ndrad\n"
#define MSGTR_DvdnavNavSeekDone "DVDNAV-hndelse: 'Nav Seek' ndrad\n"
/*
 * FIXME A lot of shorted words, not translating atm
 */

// mencoder.c:

#define MSGTR_UsingPass3ControllFile "Anvnder pass3-kontrollfil: %s\n"
#define MSGTR_MissingFilename "\nFilnamn saknas.\n\n"
#define MSGTR_CannotOpenFile_Device "Kan inte ppna fil/enhet.\n"
#define MSGTR_CannotOpenDemuxer "Kan inte ppna demuxer.\n"
#define MSGTR_NoAudioEncoderSelected "\nIngen audioencoder (-oac) vald. Vlj en (se -oac help) eller anvnd -nosound.\n"
#define MSGTR_NoVideoEncoderSelected "\nIngen videoencoder (-ovc) vald. Vlj en (se -ovc help).\n"
#define MSGTR_CannotOpenOutputFile "Kan inte ppna utfil '%s'.\n"
#define MSGTR_EncoderOpenFailed "Misslyckade att ppna encodern.\n"
#define MSGTR_ForcingOutputFourcc "Forcerar utmatning 'fourcc' till %x [%.4s]\n" // FIXME fourcc?
#define MSGTR_WritingAVIHeader "Skriver AVI-filhuvud...\n"
#define MSGTR_DuplicateFrames "\n%d duplicerad bildruta/or!\n"
#define MSGTR_SkipFrame "\nHoppar ver bildruta!\n"
#define MSGTR_ErrorWritingFile "%s: Fel vid skrivning till fil.\n"
#define MSGTR_WritingAVIIndex "\nSkriver AVI-index...\n"
#define MSGTR_FixupAVIHeader "Fixering AVI-filhuvud...\n" // FIXME fixing?
#define MSGTR_RecommendedVideoBitrate "Rekommenderad videobitrate fr %s CD: %d\n"
#define MSGTR_VideoStreamResult "\nVideostm: %8.3f kbit/s  (%d B/s)  storlek: %d byte  %5.3f sekunder  %d bildrutor\n"
#define MSGTR_AudioStreamResult "\nAudiostm: %8.3f kbit/s  (%d B/s)  storlek: %d byte  %5.3f sekunder\n"
#define MSGTR_OpenedStream "klart: format: %d  data: 0x%X - 0x%x\n"
#define MSGTR_VCodecFramecopy "videocodec: framecopy (%dx%d %dbpp fourcc=%x)\n" // FIXME translate?
#define MSGTR_ACodecFramecopy "audiocodec: framecopy (format=%x chans=%d rate=%ld bits=%d B/s=%ld sample-%ld)\n" // -''-
#define MSGTR_CBRPCMAudioSelected "CBR PCM audio valt\n"
#define MSGTR_MP3AudioSelected "MP3 audio valt\n"
#define MSGTR_CannotAllocateBytes "Kunde inte allokera %d byte\n"
#define MSGTR_SettingAudioDelay "Stter AUDIO DELAY till %5.3f\n"
#define MSGTR_SettingAudioInputGain "Stter 'audio input gain' till %f\n" // FIXME to translate?
#define MSGTR_LamePresetEquals "\npreset=%s\n\n" // FIXME translate?
#define MSGTR_LimitingAudioPreload "Begrnsar audiofrinladdning till 0.4s\n" // preload?
#define MSGTR_IncreasingAudioDensity "Hjer audiodensitet till 4\n"
#define MSGTR_ZeroingAudioPreloadAndMaxPtsCorrection "Forcerar audiofrinladdning till 0, 'max pts correction' till 0\n"
#define MSGTR_CBRAudioByterate "\n\nCBR audio: %ld byte/sec, %d byte/block\n"
#define MSGTR_LameVersion "LAME version %s (%s)\n\n"
#define MSGTR_InvalidBitrateForLamePreset "Fel: Angiven bitrate r utanfr godknd rymd fr detta val\n"\
    "\n"\
"Vid anvndning av detta val s mste du ange ett vrde mellan \"8\" och \"320\"\n"\
"\n"\
"Fr vidare information testa: \"-lameopts preset=help\"\n"
#define MSGTR_InvalidLamePresetOptions "Fel: du angav inte en godknd profil och/eller frinstllda val\n"\
    "\n"\
"Tillgngliga profiler r:\n"\
"\n"\
"   <fast>        standard\n"\
"   <fast>        extreme\n"\
"                 insane\n"\
"   <cbr> (ABR Mode) - ABR-mode r underfrsttt. Fr att anvnda det,,\n"\
"                      helpt enkelt ange en bitrate. Fr exempel:\n"\
"                      \"preset=185\" aktiverar detta\n"\
"                      frinstllda val, och anvnder 185 som ett genomsnittlig kbps.\n"\
"\n"\
"    Ngra exempel:\n"\
"\n"\
"       \"-lameopts fast:preset=standard  \"\n"\
" eller \"-lameopts  cbr:preset=192       \"\n"\
" eller \"-lameopts      preset=172       \"\n"\
" eller \"-lameopts      preset=extreme   \"\n"\
"\n"\
"Fr vidare information, frsk: \"-lameopts preset=help\"\n"
#define MSGTR_LamePresetsLongInfo "\n"\
    "De frinstllda switcharna r designade fr att frsrja den hgsta mjliga kvalit.\n"\
"\n"\
"De har fr mestadels blivit utsatta fr och instmmnt via rigorsa dubbelblindslystningstester\n"\
"fr att verifiera och stakomma detta ml.\n"\
"\n"\
"Dessa r ideligen uppdaterade fr att sammantrffa med de senaste utveckling som\n"\
"frekommer, och som result skulle frsrja dig med bortt den bsta kvalit\n"\
"fr stunden mjligt frn LAME.\n"\
"\n"\
"Fr att aktivera dessa frinstllda vrden:\n"\
"\n"\
"   Fr VBR-modes (generellt hgsta kvalit) \b:\n"\
"\n"\
"     \"preset=standard\" Denna frinstllning torde generellt vara transparent\n"\
"                             fr de flesta fr den mesta musik och har redan\n"\
"                             relativt hg kvalit.\n"\
"\n"\
"     \"preset=extreme\" Om du har extremt god hrsel och liknande utrustning,\n"\
"                             d kommer denna instllning generellt att tillgodose\n"\
"                             ngot hgre kvalit n \"standard\"-instllningen\n"\
"\n"\
"   Fr 'CBR 320kbps' (hgsta mjliga kvalit frn frinstllningsswitcharna):\n"\
                                                                               "\n"\
"     \"preset=insane\"  Denna frinstllning kommer troligen att vara fr mycket fr de\n"\
"                             flesta och de flesta situationer, men om du mste absolut\n"\
"                             ha den hgsta mjliga kvalit med inga invndningar om\n"\
"                             filstorleken s r detta den vg att g.\n"\
"\n"\
"   Fr ABR-modes (hg kvalit per given bitrate, men inte s hg som fr VBR) \b:\n"\
"\n"\
"     \"preset=<kbps>\"  Anvndning av denna instllning vill fr det mesta ge dig god\n"\
"                             kvalit vid specifik bitrate, Beroende p angiven bitrate,\n"\
"                             denna instllning kommer att anta den mest optimala instllning\n"\
"                             fr en optimal situation. Fast detta tillvgagngsstt fungerar,\n"\
"                             s r den inte tillnrmandesvis s flexibelt som VBR, och fr det\n"\
"                             mesta s kommer den inte att komma t samma niv av kvalit som\n"\
"                             VBR vid hgre bitrate.\n"\
"\n"\
"Fljande instllningar r ven tillgngliga fr motsvarande profil:\n"\
"\n"\
"   <fast>        standard\n"\
"   <fast>        extreme\n"\
"                 insane\n"\
"   <cbr> (ABR Mode) - ABR-mode r underfrsttt. Fr att anvnda det,\n"\
"                      helt enkelt ange en bitrate. Fr exempel:\n"\
"                      \"preset=185\" aktiverar denna instllning\n"\
"                      och anvnder 185 som ett genomsnittlig kbps.\n"\
"\n"\
"   \"fast\" - Aktiverar den nya snabba VBR fe en speciell profil.\n"\
"            Nackdel till snabbhetsswitchen r att oftast kommer\n"\
"            bitrate att vara ngot hgre n vid 'normal'-mode\n"\
"            och kvalitn kan ven bil ngot lgre.\n"\
"   Varning: Med aktuell version kan 'fast'-instllningen resultera i\n"\
"            fr hr bitrate i jmfrelse med ordinarie instllning.\n"\
"\n"\
"   \"cbr\"  - Om du anvnder ABR-mode (ls ovanstende) med en signifikant\n"\
"            bitrate, ssom 80, 96, 112, 128, 160, 192, 224, 256, 320,\n"\
"            du kan anvnda \"cbr\"-argument fr att forcera CBR-modeskodning\n"\
"            istllet fr som standard ABR-mode. ABR gr hgre kvalit\n"\
"            men CBR kan vara anvndbar i situationer ssom vid strmmande\n"\
"            av mp3 ver internet.\n"\
"\n"\
"    Till exempel:\n"\
"\n"\
"    \"-lameopts fast:preset=standard  \"\n"\
" or \"-lameopts  cbr:preset=192       \"\n"\
" or \"-lameopts      preset=172       \"\n"\
" or \"-lameopts      preset=extreme   \"\n"\
"\n"\
"\n"\
"Ett par alias r tillgngliga fr ABR-mode:\n"\
"phone => 16kbps/mono        phon+/lw/mw-eu/sw => 24kbps/mono\n"\
"mw-us => 40kbps/mono        voice => 56kbps/mono\n"\
"fm/radio/tape => 112kbps    hifi => 160kbps\n"\
"cd => 192kbps               studio => 256kbps"
#define MSGTR_ConfigfileError "konfigurationsfilsfel"
#define MSGTR_ErrorParsingCommandLine "fel vid tolkning av cmdline"
#define MSGTR_VideoStreamRequired "Videostrm r obligatoriskt!\n"
#define MSGTR_ForcingInputFPS "'input fps' kommer att bli tolkad som %5.2f istllet\n"
#define MSGTR_RawvideoDoesNotSupportAudio "Ut-filformat RAWVIDEO stdjer inte audio - deaktiverar audio\n"
#define MSGTR_DemuxerDoesntSupportNosound "Denna demuxer stdjer inte -nosound nnu.\n"
#define MSGTR_MemAllocFailed "minnesallokering misslyckades"
#define MSGTR_NoMatchingFilter "Kunde inte finna matchande filter/ao-format!\n"
#define MSGTR_MP3WaveFormatSizeNot30 "sizeof(MPEGLAYER3WAVEFORMAT)==%d!=30, kanske trasig C-kompilator?\n"
#define MSGTR_NoLavcAudioCodecName "Audio LAVC, frkommet codecsnamn!\n"
#define MSGTR_LavcAudioCodecNotFound "Audio LAVC, kunde inte finna encoder fr codec %s\n"
#define MSGTR_CouldntAllocateLavcContext "Audio LAVC, kunde inte allokera kontext!\n"
#define MSGTR_CouldntOpenCodec "Kunde inte ppna codec %s, br=%d\n"

// cfg-mencoder.h:

#define MSGTR_MEncoderMP3LameHelp "\n\n"\
    " vbr=<0-4>     variabel bitrate metod\n"\
"                0: cbr\n"\
"                1: mt\n"\
"                2: rh(default)\n"\
"                3: abr\n"\
"                4: mtrh\n"\
"\n"\
" abr           medelbitrate\n"\
"\n"\
" cbr           konstant bitrate\n"\
"               ven forcerar CBR-modeskodning p subsequentiellt ABR-instllningslge.\n"\
"\n"\
" br=<0-1024>   specifierar bitrate i kBit (CBR och ABR endast)\n"\
"\n"\
" q=<0-9>       kvalit (0-hgst, 9-lgst) (endast fr VBR)\n"\
"\n"\
" aq=<0-9>      algoritmiskt kvalit (0-bst/segast, 9-smst/snabbast)\n"\
"\n"\
" ratio=<1-100> kompressionsratio\n"\
"\n"\
" vol=<0-10>    stt audio-in-kning\n"\
"\n"\
" mode=<0-3>    (standard: auto)\n"\
"                0: stereo\n"\
"                1: joint-stereo\n"\
"                2: dualchannel\n"\
"                3: mono\n"\
"\n"\
" padding=<0-2>\n"\
"                0: no\n"\
"                1: all\n"\
"                2: adjust\n"\
"\n"\
" fast          Aktivera snabbare kodning p subsequentiellt VBR-instllningslge,\n"\
"               ngot lgre kvalit och hgre bitrate.\n"\
"\n"\
" preset=<value> Tillhandahller den hgsta tillgngliga kvalittsinstllning.\n"\
"                 medium: VBR  kodning, godkvalit\n"\
"                 (150-180 kbps bitratesrymd)\n"\
"                 standard:  VBR kodning, hg kvalit\n"\
"                 (170-210 kbps bitratesrymd)\n"\
"                 extreme: VBR kodning, mycket hg kvalit\n"\
"                 (200-240 kbps bitratesrymd)\n"\
"                 insane:  CBR  kodning, hgsta frinstlld kvalit\n"\
"                 (320 kbps bitrate)\n"\
"                 <8-320>: ABR kodning vid i medeltal angiven bitrate (kbps).\n\n"

//codec-cfg.c:

#define MSGTR_DuplicateFourcc "duplicerad FourCC"
#define MSGTR_TooManyFourccs "fr mnga FourCCs/format..."
#define MSGTR_ParseError "tolkningsfel"
#define MSGTR_ParseErrorFIDNotNumber "tolkningsfel (format-ID r inget nummer?)"
#define MSGTR_ParseErrorFIDAliasNotNumber "tolkningsfel (format-ID-alias r inget nummer?)"
#define MSGTR_DuplicateFID "duplicerade format-ID"
#define MSGTR_TooManyOut "fr mnga ut..." //FIXME 'to many out'?
#define MSGTR_InvalidCodecName "\ncodec(%s) namn r icke godknt!\n"
#define MSGTR_CodecLacksFourcc "\ncodec(%s) har inte FourCC/format!\n"
#define MSGTR_CodecLacksDriver "\ncodec(%s) har ingen drivrutin!\n"
#define MSGTR_CodecNeedsDLL "\ncodec(%s) behver en 'dll'!\n"
#define MSGTR_CodecNeedsOutfmt "\ncodec(%s) behver en 'outfmt'!\n"
#define MSGTR_CantAllocateComment "Kan inte allokera minne flr kommentar. "
#define MSGTR_GetTokenMaxNotLessThanMAX_NR_TOKEN "get_token() \b: max >= MAX_MR_TOKEN!" //FIXME translate?
#define MSGTR_ReadingFile "Lser %s: "
#define MSGTR_CantOpenFileError "Kan inte ppna '%s': %s\n"
#define MSGTR_CantGetMemoryForLine "Kan inte f minne fr 'line': %s\n"
#define MSGTR_CantReallocCodecsp "Kan inte realloc '*codecsp': %s\n"
#define MSGTR_CodecNameNotUnique "Codec namn '%s' r inte unikt."
#define MSGTR_CantStrdupName "Kan inte strdup -> 'name': %s\n"
#define MSGTR_CantStrdupInfo "Kan inte strdup -> 'info': %s\n"
#define MSGTR_CantStrdupDriver "Kan inte strdup -> 'driver': %s\n"
#define MSGTR_CantStrdupDLL "Kan inte strdup -> 'dll': %s"
#define MSGTR_AudioVideoCodecTotals "%d audio & %d video codecs\n"
#define MSGTR_CodecDefinitionIncorrect "Codec r inte definerad korrekt."
#define MSGTR_OutdatedCodecsConf "Denna codecs.conf r fr gammal och inkompatibel med denna MPlayer version!" // release is more like 'slpp', sounds wrong, using version instead
// divx4_vbr.c:
#define MSGTR_OutOfMemory "slut p minne"

// FIXME chip? chips or kort?
#define MSGTR_OverridingTooLowBitrate "Specifierad bitrate r fr lg fr detta chips.\n"\
"Minimal mjlig bitrate fr detta chips r %.0f Kbps. Skriver ver\n"\
"anvndarspecificerade vrden.\n"

// fifo.c
#define MSGTR_CannotMakePipe "Kan inte skapa en PIPE!\n" // FIXME make? 

// m_config.c
#define MSGTR_SaveSlotTooOld "Allt fr gammal sparningsslottar funna frn niv %d: %d !!!\n" // FIXME slot?
#define MSGTR_InvalidCfgfileOption "Alternativ %s kan inte anvndas i en konfigurationsfil\n"
#define MSGTR_InvalidCmdlineOption "Alternativ %s kan inte bli anvnds som ett kommandoradsargument\n"
#define MSGTR_InvalidSuboption "Fel: alternativ '%s' har inga underalternativ '%s'\n" // FIXME suboption?
#define MSGTR_MissingSuboptionParameter "Fel: underalternativ '%s' av '%s' mste ha en parameter!\n" // FIXME Don't know what seccond %s is, perhaps totaly wrong to have 'av' there 
#define MSGTR_MissingOptionParameter "Fel: alternativ '%s' mste ha en parameter!\n"
#define MSGTR_OptionListHeader "\n Namn                 Typ             Min        Max      Global  CL    Cfg\n\n" // TODO why static tabs?
#define MSGTR_TotalOptions "\nTotalt: %d alternativ\n"

// open.c, stream.c:
#define MSGTR_CdDevNotfound "CD-ROM-enhet '%s' ej funnet.\n"
#define MSGTR_ErrTrackSelect "Fel vid val av VCD-spr."
#define MSGTR_ReadSTDIN "Lser frn stdin...\n"
#define MSGTR_UnableOpenURL "Ofrmgen att ppna URL: %s\n"
#define MSGTR_ConnToServer "Ansluten till server: %s\n"
#define MSGTR_FileNotFound "Fil ej funnen: '%s'\n"

#define MSGTR_SMBInitError "Kan inte initiera libsmbclient-bilioteket: %d\n"
#define MSGTR_SMBFileNotFound "Kunde inte ppna frn LAN: '%s'\n"
#define MSGTR_SMBNotCompiled "MPlayer var inte kompilerad med SMB-lsstd.\n"

#define MSGTR_CantOpenDVD "Kunde inte ppna DVD-enhet: %s\n"
#define MSGTR_DVDwait "Lser diskstruktur, var god drj...\n"
#define MSGTR_DVDnumTitles "Det r %d titlar p denna DVD.\n"
#define MSGTR_DVDinvalidTitle "Icke godknt DVD-titelnummer: %d\n"
#define MSGTR_DVDnumChapters "Der r %d kapitel p denna DVD-titel.\n"
#define MSGTR_DVDinvalidChapter "Ej godknt DVD-kapitelnummer: %d\n"
#define MSGTR_DVDnumAngles "Det r %d vinkar p denna DVD-titel.\n"
#define MSGTR_DVDinvalidAngle "Ej godknd DVD-vinkelsnummer: %d\n"
#define MSGTR_DVDnoIFO "Kan inte ppna IFO-fil fr DVD-titel %d.\n"
#define MSGTR_DVDnoVOBs "Kunde inte ppna titel VOBS (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDopenOk "DVD ppnades problemfritt.\n"

// demuxer.c, demux_*.c:

#define MSGTR_AudioStreamRedefined "VARNING: Audiostrmsfilhuvud %d omdefinerad.\n"
#define MSGTR_VideoStreamRedefined "WARNING: Videostrmsfilhuvud %d omdefinerad.\n"
#define MSGTR_TooManyAudioInBuffer "\nAllt fr mnga audiopaket i bufferten: (%d i %d byte).\n"
#define MSGTR_TooManyVideoInBuffer "\nAllt fr mnga videopaket i bufferten: (%d i %d byte).\n"
#define MSGTR_MaybeNI "Kanske frsker du spela upp en icke-interleaved strm/fil, eller s har decodern falierat?\n" \
    "Fr AVI-filer, frsk med att forcera icke-interleaved-lgen med -ni argumentet.\n" // FIXME non-interleaved
#define MSGTR_SwitchToNi "\nSvrt interleaved AVI-fil detekterad, gr ver till '-ni'-lge...\n"
#define MSGTR_Detected_XXX_FileFormat "%s filformat detekterat.\n"
#define MSGTR_DetectedAudiofile "Audiofilformat detekterat.\n"
#define MSGTR_NotSystemStream "Icke 'MPEG System Stream'-format... (kanske Transport Stream?)\n"
#define MSGTR_InvalidMPEGES "Icke godknd 'MPEG-ES'-strm??? Kontakta upphovsmannen, det kanske r en bugg :(\n" //FIXME author???
#define MSGTR_FormatNotRecognized "================ Tyvrr, detta filformat r inte rekogniserbart/sttt ==================\n"\
    "=== Om denna fil r en AVi, ASF eller MPEG-strm, var vnlig kontakta upphovsmannen! ===\n" //FIXME author???
#define MSGTR_MissingVideoStream "Ingen videostrm funnen.\n"
#define MSGTR_MissingAudioStream "Ingen audiostrm funnen -> inget ljud.\n"
#define MSGTR_MissingVideoStreamBug "Saknar videostrm!? Kontakta upphovsmannen, det kan vara en bugg :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: Fil innehller ej den valda audio- eller videostrmmen.\n"

#define MSGTR_NI_Forced "Forcerad"
#define MSGTR_NI_Detected "Pvisad" // FIXME right to say?
#define MSGTR_NI_Message "%s 'NON-INTERLEAVED AVI'-filformat.\n"

#define MSGTR_UsingNINI "Anvnder trasig 'NON-INTERLEAVED AVI'-filformat.\n"
#define MSGTR_CouldntDetFNo "Kunde inte avgra antalet bildrutor (fr absolut skning).\n"
#define MSGTR_CantSeekRawAVI "Kan inte ska i ra AVI-strmmar. (Index krvs, frsk med '-idx'-switchen.)\n"
#define MSGTR_CantSeekFile "Kan inte ska i denna fil.\n"

#define MSGTR_EncryptedVOB "Krypterad VOB-fil! Read DOCS/HTML/en/dvd.html.\n"

#define MSGTR_MOVcomprhdr "MOV: filhuvudkomprimeringssupport krver ZLIB!\n"
#define MSGTR_MOVvariableFourCC "MOV: VARNING: Variabel FOURCC pvisad!?\n"
#define MSGTR_MOVtooManyTrk "MOV: VARNING: allt frmnga spr"
#define MSGTR_FoundAudioStream "==> Fann audiostrm: %d\n"
#define MSGTR_FoundVideoStream "==> Fann videostrm: %d\n"
#define MSGTR_DetectedTV "TV pvisad! ;-)\n"
#define MSGTR_ErrorOpeningOGGDemuxer "Ofrmgen att ppna oggdemuxern.\n"
#define MSGTR_ASFSearchingForAudioStream "ASF: Sker efter audiostrm (id:%d).\n"
#define MSGTR_CannotOpenAudioStream "Kan inte ppna audiostrm: %s\n"
#define MSGTR_CannotOpenSubtitlesStream "Kan inte ppna textningsstrm: %s\n"
#define MSGTR_OpeningAudioDemuxerFailed "Misslyckades att ppna audiodemuxern: %s\n"
#define MSGTR_OpeningSubtitlesDemuxerFailed "Misslyckades att ppna textningsdemuxern: %s\n"
#define MSGTR_TVInputNotSeekable "TV-in r inte skbar! (Skning kommer troligen bli fr att ndra kanal ;)\n"
#define MSGTR_DemuxerInfoAlreadyPresent "Demuxerinfo %s redan instlld!\n"
#define MSGTR_ClipInfo "Clip-info:\n"

#define MSGTR_LeaveTelecineMode "\ndemux_mpg: '30fps NTSC'-innehll upptckt, ndrar framerate.\n" // FIXME framerate?
#define MSGTR_EnterTelecineMode "\ndemux_mpg: '24fps progressive NTSC'-innehll upptckt, ndrar framerate.\n" // -''-

// dec_video.c & dec_audio.c:

#define MSGTR_CantOpenCodec "Kunde inte ppna codec.\n"
#define MSGTR_CantCloseCodec "Kunde inte stnga codec\n"

#define MSGTR_MissingDLLcodec "FEL: Kunde inte ppna obligatorisk DirecShow-codec %s.\n"
#define MSGTR_ACMiniterror "Kunde inte ladda/initiera 'Win32/ACM AUDIO'-codec (saknas Dll-fil?).\n"
#define MSGTR_MissingLAVCcodec "Kunde inte finna codec '%s' i libavcodec...\n"

#define MSGTR_MpegNoSequHdr "MPEG: FATAL: EOF under skning efter sequencefilhuvuden\n" // FIXME sequence?
#define MSGTR_CannotReadMpegSequHdr "FATAL: Kunde inte lsa sequencefilhuvud\n"
#define MSGTR_CannotReadMpegSequHdrEx "FATAL: Kunde inte lsa sequencefilhuvudstillgg.\n"
#define MSGTR_BadMpegSequHdr "MPEG: dlig sequencefilhuvud\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: dlig sequencefilhuvudstillgg\n"

#define MSGTR_ShMemAllocFail "Kunde inte allokera delat minne.\n"
#define MSGTR_CantAllocAudioBuf "Kunde inte allokera audio-ut-buffert.\n"

#define MSGTR_UnknownAudio "Oknd/saknad audioformat -> inget ljud\n"

#define MSGTR_UsingExternalPP "[PP] Anvnder externt postprocesseringsfiler, max q = %d.\n"
#define MSGTR_UsingCodecPP "[PP] Anvnder codecens postprocessing, max q = %d.\n"
#define MSGTR_VideoAttributeNotSupportedByVO_VD "Videoattribut '%s' har inget std hos vald vo & vd.\n" // FIXME more info? vo & vd
#define MSGTR_VideoCodecFamilyNotAvailableStr "Begrd videocodecfamilj [%s] (vfm=%s) r ej tillgnglig.\nAktivera det vil kompilation.\n"
#define MSGTR_AudioCodecFamilyNotAvailableStr "Begrd audiocodecfamilj [%s] (afm=%s) r ej tillgnglig.\nAktivera det vil kompilation.\n"
#define MSGTR_OpeningVideoDecoder "ppnar videodecoder: [%s] %s\n"
#define MSGTR_OpeningAudioDecoder "ppnar audiodecoder: [%s] %s\n"
#define MSGTR_UninitVideoStr "uninit video: %s\n" // FIXME translate?
#define MSGTR_UninitAudioStr "uninit audio: %s\n" // -''-
#define MSGTR_VDecoderInitFailed "VDecoder-initiering misslyckades :(\n" // FIXME VDecoder something special or just a shortcut?
#define MSGTR_ADecoderInitFailed "ADecoder-initiering misslyckades :(\n" // -''-
#define MSGTR_ADecoderPreinitFailed "ADecoder-preinitiering misslyckades :(\n" // -''-
#define MSGTR_AllocatingBytesForInputBuffer "dec_audio: Allokerar %d byte fr inbuffert.\n"
#define MSGTR_AllocatingBytesForOutputBuffer "dec_audio: Allokerar %d + %d = %d byte fr utbuffert.\n"

// LIRC:

#define MSGTR_SettingUpLIRC "Aktiverar LIRC-std...\n"
#define MSGTR_LIRCdisabled "Du kommer inte att kunna anvnda din fjrrkontroll.\n"
#define MSGTR_LIRCopenfailed "Misslyckades med att aktivera LIRC-std.\n"
#define MSGTR_LIRCcfgerr "Misslyckades med att lsa LIRC-konfigurationsfil %s.\n"

// vf.c

#define MSGTR_CouldNotFindVideoFilter "Kunde inte finna videofilter '%s'.\n"
#define MSGTR_CouldNotOpenVideoFilter "Kunde inte ppna videofilter '%s'.\n"
#define MSGTR_OpeningVideoFilter "ppnar videofilter: "
#define MSGTR_CannotFindColorspace "Kunde inte hitta matchande frgrymder, t.o.m. vid insttning av 'scale' :(\n" // FIXME colorspace

// vd.c

#define MSGTR_CodecDidNotSet "VDec: Codec satt inte sh->disp_w samt sh->disp_h, frsker g runt problemet.\n"
#define MSGTR_VoConfigRequest "VDec: vo-konfigurationsbegran - %d x %d (preferred csp: %s)\n"
#define MSGTR_CouldNotFindColorspace "Kunde inte finna matchande frgrymder - frsker ter med -vf scale...\n" // -''-
#define MSGTR_MovieAspectIsSet "Movie-Aspect r %.2f:1 - prescaling till korrekt film-aspect.\n"
#define MSGTR_MovieAspectUndefined "Film-Aspect r ej definerad - ingen prescaling kommer att ga rum.\n"

// vd_dshow.c, vd_dmo.c

#define MSGTR_DownloadCodecPackage "Du mste uppgradera/installera de binra codecspaketen.\nG till http://www.mplayerhq.hu/dload.html\n"
#define MSGTR_DShowInitOK "INFO: 'Win32/DShow'-videocodecinitiering: OK.\n"
#define MSGTR_DMOInitOK "INFO: 'Win32/DMO'-videocodecinitiering: OK.\n"

// x11_common.c

#define MSGTR_EwmhFullscreenStateFailed "\nX11: Kunde inte snda EWMH-fullskrmshndelse!\n"

#define MSGTR_InsertingAfVolume "[Mixer] Ingen hrdvarumixning, lgger till volymfilter.\n"
#define MSGTR_NoVolume "[Mixer] Ingen volymkontroll tillgnglig.\n"


// ====================== GUI messages/buttons ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About "Om"
#define MSGTR_FileSelect "Vlj fil..."
#define MSGTR_SubtitleSelect "Vlj textning..."
#define MSGTR_OtherSelect "Vlj..."
#define MSGTR_AudioFileSelect "Vlj extern audiokanal..."
#define MSGTR_FontSelect "Vlj font..."
#define MSGTR_PlayList "Spellista"
#define MSGTR_Equalizer "Equalizer" 
#define MSGTR_SkinBrowser "Skinlsare"
#define MSGTR_Network "Ntverksstrmning..."
#define MSGTR_Preferences "Instllningar"
#define MSGTR_AudioPreferences "Audiodirvrutinskonfiguration"
#define MSGTR_NoMediaOpened "Inget media ppnad"
#define MSGTR_VCDTrack "VCD-spr %d"
#define MSGTR_NoChapter "Inget kapitel"
#define MSGTR_Chapter "Kapitel %d"
#define MSGTR_NoFileLoaded "Ingen fil laddad"

// --- buttons ---

#define MSGTR_Ok "OK"
#define MSGTR_Cancel "Avbryt"
#define MSGTR_Add "Lgg till"
#define MSGTR_Remove "Radera"
#define MSGTR_Clear "Rensa"
#define MSGTR_Config "Konfiguration"
#define MSGTR_ConfigDriver "Konfigurera drivrution"
#define MSGTR_Browse "Blddra"

// --- error messages ---

#define MSGTR_NEMDB "Tyvrr, inte tillrckligt minne fr ritbuffert."
#define MSGTR_NEMFMR "Tyvrr, inte tillrckligt minne fr menyrendering."
#define MSGTR_IDFGCVD "Tyvrr, jag hittade inte en GUI-kompatibel video-ut-drivrutin."
#define MSGTR_NEEDLAVCFAME "Tyvrr, du kan inte spela icke-MPEG-filer med ditt DXR3/H+-enhet utan omkodning.\nVar god aktivera lavc eller fame i 'DXR3/H+'-konfigurationsboxen."

// --- skin loader error messages

#define MSGTR_SKIN_ERRORMESSAGE "[skin] fel i skinkonfigureringsfil p rad %d: %s"
#define MSGTR_SKIN_WARNING1 "[skin] varning i konfigurationsfil p rad %d:\nwidget (%s) funnen, men ingen \"section\" funnen fre"
#define MSGTR_SKIN_WARNING2 "[skin] varning i konfigurationsfil p rad %d:\nwidget (%s) funnen, men ingen \"subsection\" funnen fre"
#define MSGTR_SKIN_WARNING3 "[skin] varning i konfigurationsfil p rad %d:\ndenna undersektion stdjs inte av widget (%s)"
#define MSGTR_SKIN_BITMAP_16bit  "16-bitar eller lgre bitmappar stdjs inte (%s).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound  "fil ej funnen (%s)\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "BMP lsfel (%s)\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "TGA lsfel (%s)\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "PNG lsfel (%s)\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "RLE-packad TGA stdjs ej (%s)\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "oknd filtyp (%s)\n"
#define MSGTR_SKIN_BITMAP_ConvertError "24-bitars till 32-bitars konverteringsfel (%s)\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "oknt meddelande: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "ej tillrckligt minne\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "Allt fr mnga fonter deklarerade.\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "Fontfil ej funnen.\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "Fontbildsfil ej funnen.\n"
#define MSGTR_SKIN_FONT_NonExistentFontID "icke-existerande fontidentifkator (%s)\n"
#define MSGTR_SKIN_UnknownParameter "oknd parameter (%s)\n"
#define MSGTR_SKIN_SKINCFG_SkinNotFound "Skin ej funnen (%s).\n"
#define MSGTR_SKIN_SKINCFG_SkinCfgReadError "skinkonfigurationsfilslsfel (%s)\n"
#define MSGTR_SKIN_LABEL "Skin:"

// --- gtk menus

#define MSGTR_MENU_AboutMPlayer "Om MPlayer"
#define MSGTR_MENU_Open "ppna..."
#define MSGTR_MENU_PlayFile "Spela fil..."
#define MSGTR_MENU_PlayVCD "Spela VCD..."
#define MSGTR_MENU_PlayDVD "Spela DVD..."
#define MSGTR_MENU_PlayURL "Spela URL..."
#define MSGTR_MENU_LoadSubtitle "Ladda textning..."
#define MSGTR_MENU_DropSubtitle "Droppa textning..."
#define MSGTR_MENU_LoadExternAudioFile "Ladda extern audiofil..."
#define MSGTR_MENU_Playing "Spelar"
#define MSGTR_MENU_Play "Spela"
#define MSGTR_MENU_Pause "Pausa"
#define MSGTR_MENU_Stop "Stopp"
#define MSGTR_MENU_NextStream "Nsta strm"
#define MSGTR_MENU_PrevStream "Fregende strm"
#define MSGTR_MENU_Size "Storlek"
#define MSGTR_MENU_NormalSize "Normal storlek"
#define MSGTR_MENU_DoubleSize "Dubbel storlek"
#define MSGTR_MENU_FullScreen "Fullskrm"
#define MSGTR_MENU_DVD "DVD"
#define MSGTR_MENU_VCD "VCD"
#define MSGTR_MENU_PlayDisc "ppnar disk..." // FIXME to open or is opening?
#define MSGTR_MENU_ShowDVDMenu "Visa DVD-meny"
#define MSGTR_MENU_Titles "Titlar"
#define MSGTR_MENU_Title "Titel %2d"
#define MSGTR_MENU_None "(ingen)"
#define MSGTR_MENU_Chapters "Kapitel"
#define MSGTR_MENU_Chapter "Kapitel %2d"
#define MSGTR_MENU_AudioLanguages "Audiosprk"
#define MSGTR_MENU_SubtitleLanguages "Textningssprk"
#define MSGTR_MENU_SkinBrowser "Skinlsare"
#define MSGTR_MENU_Exit "Avsluta..."
#define MSGTR_MENU_Mute "Dmpa"
#define MSGTR_MENU_Original "Orginal"
#define MSGTR_MENU_AspectRatio "Aspect ratio" // FIXME translate?
#define MSGTR_MENU_AudioTrack "Audiospr"
#define MSGTR_MENU_Track "Spr %d"
#define MSGTR_MENU_VideoTrack "Videospr"

// --- equalizer

#define MSGTR_EQU_Audio "Audio"
#define MSGTR_EQU_Video "Video"
#define MSGTR_EQU_Contrast "Kontrast: "
#define MSGTR_EQU_Brightness "Ljusstyrka: "
#define MSGTR_EQU_Hue "Hue: "
#define MSGTR_EQU_Saturation "Saturation: "
#define MSGTR_EQU_Front_Left "Vnster fram"
#define MSGTR_EQU_Front_Right "Hger fram"
#define MSGTR_EQU_Back_Left "Vnster bak"
#define MSGTR_EQU_Back_Right "Hger bak"
#define MSGTR_EQU_Center "Center"
#define MSGTR_EQU_Bass "Bass"
#define MSGTR_EQU_All "Allt"
#define MSGTR_EQU_Channel1 "Kanal 1:"
#define MSGTR_EQU_Channel2 "Kanal 2:"
#define MSGTR_EQU_Channel3 "Kanal 3:"
#define MSGTR_EQU_Channel4 "Kanal 4:"
#define MSGTR_EQU_Channel5 "Kanal 5:"
#define MSGTR_EQU_Channel6 "Kanal 6:"

// --- playlist

#define MSGTR_PLAYLIST_Path "Skvg"
#define MSGTR_PLAYLIST_Selected "Valda filer"
#define MSGTR_PLAYLIST_Files "Filer"
#define MSGTR_PLAYLIST_DirectoryTree "Katalogtrd"

// --- preferences

#define MSGTR_PREFERENCES_SubtitleOSD "Textning & OSD"
#define MSGTR_PREFERENCES_Codecs "Codecs & demuxer"
#define MSGTR_PREFERENCES_Misc "Diverse"

#define MSGTR_PREFERENCES_None "Inget"
#define MSGTR_PREFERENCES_DriverDefault "standarddrivrutin"
#define MSGTR_PREFERENCES_AvailableDrivers "Tillgngliga drivrutioner:"
#define MSGTR_PREFERENCES_DoNotPlaySound "Spela inte upp ljud"
#define MSGTR_PREFERENCES_NormalizeSound "Normalizera ljud"
#define MSGTR_PREFERENCES_EnEqualizer "AKtivera equalizer"
#define MSGTR_PREFERENCES_ExtraStereo "Aktivera extra stereo"
#define MSGTR_PREFERENCES_Coefficient "Koefficient:"
#define MSGTR_PREFERENCES_AudioDelay "Audiofrdrjning"
#define MSGTR_PREFERENCES_DoubleBuffer "Aktivera double buffering"
#define MSGTR_PREFERENCES_DirectRender "Aktivera direct rendering"
#define MSGTR_PREFERENCES_FrameDrop "Aktivera frame dropping"
#define MSGTR_PREFERENCES_HFrameDrop "Aktivera HRD frame dropping (dangerous)"
#define MSGTR_PREFERENCES_Flip "Flippa bilden uppochner"
#define MSGTR_PREFERENCES_Panscan "Panscan: "
#define MSGTR_PREFERENCES_OSDTimer "Timers och indikatorer"
#define MSGTR_PREFERENCES_OSDProgress "Tillstndsrad endast"
#define MSGTR_PREFERENCES_OSDTimerPercentageTotalTime "Timer, procent och total tid"
#define MSGTR_PREFERENCES_Subtitle "Textning:"
#define MSGTR_PREFERENCES_SUB_Delay "Frdrjning: "
#define MSGTR_PREFERENCES_SUB_FPS "FPS:"
#define MSGTR_PREFERENCES_SUB_POS "Position: "
#define MSGTR_PREFERENCES_SUB_AutoLoad "Deaktivera automatisk laddning av textning"
#define MSGTR_PREFERENCES_SUB_Unicode "Unicodetextning"
#define MSGTR_PREFERENCES_SUB_MPSUB "Konvertera given text till MPlayers egna textningsformat"
#define MSGTR_PREFERENCES_SUB_SRT "Konvertera given text till det tidbaserade SubViewer (SRT) formatet"
#define MSGTR_PREFERENCES_SUB_Overlap "Aktivera textningsverlappning"
#define MSGTR_PREFERENCES_Font "Font:"
#define MSGTR_PREFERENCES_FontFactor "Fontfaktor:"
#define MSGTR_PREFERENCES_PostProcess "Aktivera postprocessing"
#define MSGTR_PREFERENCES_AutoQuality "Autokvalit: "
#define MSGTR_PREFERENCES_NI "Anvnd non-interleaved AVI tolk"
#define MSGTR_PREFERENCES_IDX "terbygg indextabell, om s behvs"
#define MSGTR_PREFERENCES_VideoCodecFamily "Videocodecfamilj:"
#define MSGTR_PREFERENCES_AudioCodecFamily "Audiocodecfamilj:"
#define MSGTR_PREFERENCES_FRAME_OSD_Level "OSD-niv"
#define MSGTR_PREFERENCES_FRAME_Subtitle "Textning"
#define MSGTR_PREFERENCES_FRAME_Font "Font"
#define MSGTR_PREFERENCES_FRAME_PostProcess "Postprocessing"
#define MSGTR_PREFERENCES_FRAME_CodecDemuxer "Codec & demuxer"
#define MSGTR_PREFERENCES_FRAME_Cache "Cache"
#define MSGTR_PREFERENCES_Audio_Device "Enhet:"
#define MSGTR_PREFERENCES_Audio_Mixer "Mixer:"
#define MSGTR_PREFERENCES_Audio_MixerChannel "Mixerkanal:"
#define MSGTR_PREFERENCES_Message "Var god komihg att du mste starta om uppspelning fr att vissa ndringar ska ta effekt!"
#define MSGTR_PREFERENCES_DXR3_VENC "Videoencoder:"
#define MSGTR_PREFERENCES_DXR3_LAVC "ANvnd LAVC (FFmpeg)"
#define MSGTR_PREFERENCES_DXR3_FAME "Anvnd FAME"

#define MSGTR_PREFERENCES_FontEncoding1 "Unicode"
#define MSGTR_PREFERENCES_FontEncoding2 "Vsteuropeiska sprk (ISO-8859-1)"
#define MSGTR_PREFERENCES_FontEncoding3 "Vsteuropeiska sprk med Euro (ISO-8859-15)"
#define MSGTR_PREFERENCES_FontEncoding4 "Slaviska/Centraleuropeiska sprk (ISO-8859-2)"
#define MSGTR_PREFERENCES_FontEncoding5 "Esperanto, Galician, Maltese, Turkiska (ISO-8859-3)" // FIXME Galician, Maltese
#define MSGTR_PREFERENCES_FontEncoding6 "ldre baltisk teckenuppsttning (ISO-8859-4)"
#define MSGTR_PREFERENCES_FontEncoding7 "Kyrilliska (ISO-8859-5)"
#define MSGTR_PREFERENCES_FontEncoding8 "Arabiska (ISO-8859-6)"
#define MSGTR_PREFERENCES_FontEncoding9 "Modern grekiska (ISO-8859-7)"
#define MSGTR_PREFERENCES_FontEncoding10 "Turkiska (ISO-8859-9)"
#define MSGTR_PREFERENCES_FontEncoding11 "Baltiska (ISO-8859-13)"
#define MSGTR_PREFERENCES_FontEncoding12 "Celtiska (ISO-8859-14)"
#define MSGTR_PREFERENCES_FontEncoding13 "Hebrew teckenuppsttningar (ISO-8859-8)"
#define MSGTR_PREFERENCES_FontEncoding14 "Ryska (KOI8-R)"
#define MSGTR_PREFERENCES_FontEncoding15 "Ukrainska, Vitrysska (KOI8-U/RU)"
#define MSGTR_PREFERENCES_FontEncoding16 "Enkel Kinesisk teckenuppsttning (CP936)"
#define MSGTR_PREFERENCES_FontEncoding17 "Traditionell Kinesisk teckenuppsttning (BIG5)"
#define MSGTR_PREFERENCES_FontEncoding18 "Japansk teckenuppsttning (SHIFT-JIS)"
#define MSGTR_PREFERENCES_FontEncoding19 "Koreansk teckenuppsttning (CP949)"
#define MSGTR_PREFERENCES_FontEncoding20 "Thailnsk teckenuppsttning (CP874)"
#define MSGTR_PREFERENCES_FontEncoding21 "Kyrilliska Windown (CP1251)"
#define MSGTR_PREFERENCES_FontEncoding22 "Slaviska/Centraleuropeiska Windows (CP1250)"

#define MSGTR_PREFERENCES_FontNoAutoScale "Ingen autoskalning"
#define MSGTR_PREFERENCES_FontPropWidth "Propotionellt mot filmbredd"
#define MSGTR_PREFERENCES_FontPropHeight "Propotionellt mot filmhjd"
#define MSGTR_PREFERENCES_FontPropDiagonal "Propotionellt mot filmdiagonalen"
#define MSGTR_PREFERENCES_FontEncoding "Kodning:"
#define MSGTR_PREFERENCES_FontBlur "Blur:"
#define MSGTR_PREFERENCES_FontOutLine "Outline:"
#define MSGTR_PREFERENCES_FontTextScale "Textskalning:"
#define MSGTR_PREFERENCES_FontOSDScale "OSDskalning:"
#define MSGTR_PREFERENCES_Cache "Cache p/av"
#define MSGTR_PREFERENCES_CacheSize "Cachestorlek: "
#define MSGTR_PREFERENCES_LoadFullscreen "Starta i fullskrm"
#define MSGTR_PREFERENCES_SaveWinPos "Spara fnsterposition"
#define MSGTR_PREFERENCES_XSCREENSAVER "Stoppa XScreenSaver"
#define MSGTR_PREFERENCES_PlayBar "Aktivera spelindikator"
#define MSGTR_PREFERENCES_AutoSync "AutoSync p/av"
#define MSGTR_PREFERENCES_AutoSyncValue "Autosync: "
#define MSGTR_PREFERENCES_CDROMDevice "CD-ROM-enhet:"
#define MSGTR_PREFERENCES_DVDDevice "DVD-enhet:"
#define MSGTR_PREFERENCES_FPS "Film-FPS:"
#define MSGTR_PREFERENCES_ShowVideoWindow "Visa videofnster nr den r inaktiv"

#define MSGTR_ABOUT_UHU "GUI-utveckling sponstrat av UHU Linux\n"
#define MSGTR_ABOUT_CoreTeam "   MPlayers krngrupp:\n"
#define MSGTR_ABOUT_AdditionalCoders "   vriga kodare:\n"
#define MSGTR_ABOUT_MainTesters "    Huvudsakliga testare:\n"

// --- messagebox

#define MSGTR_MSGBOX_LABEL_FatalError "Overkomligt fel!"
#define MSGTR_MSGBOX_LABEL_Error "Fel!"
#define MSGTR_MSGBOX_LABEL_Warning "Varning!"

#endif

// ======================= VO Video Output drivers ========================

#define MSGTR_VOincompCodec "Vald video-ut-enhet r inte kompatibel med denna codec.\n"
#define MSGTR_VO_GenericError "Detta fel har intrffat"
#define MSGTR_VO_UnableToAccess "Kan inte accessa"
#define MSGTR_VO_ExistsButNoDirectory "finns redan, men r inte en katalog."
#define MSGTR_VO_DirExistsButNotWritable "Ut-katalog finns redan, men r inte skrivbar."
#define MSGTR_VO_DirExistsAndIsWritable "Utkatalog finns redan och r skrivbar."
#define MSGTR_VO_CantCreateDirectory "Ofrmgen att skapa ut-katalog."
#define MSGTR_VO_CantCreateFile "Ofrmgen att skapa utfil."
#define MSGTR_VO_DirectoryCreateSuccess "Ut-katalog skapad."
#define MSGTR_VO_ParsingSuboptions "Tolkar suboptions." // FIXME suboptions?
#define MSGTR_VO_SuboptionsParsedOK "Suboptions tolkad OK." // -''-
#define MSGTR_VO_ValueOutOfRange "Vrden utanfr godknd rymd"
#define MSGTR_VO_NoValueSpecified "Inget vrde angett."
#define MSGTR_VO_UnknownSuboptions "Oknd suboption" // -''-

// vo_jpeg.c

#define MSGTR_VO_JPEG_ProgressiveJPEG "'Progressive JPEG' aktiverat."
#define MSGTR_VO_JPEG_NoProgressiveJPEG "'Progressive JPEG' deaktiverat."
#define MSGTR_VO_JPEG_BaselineJPEG "'Baseline JPEG' aktiverat."
#define MSGTR_VO_JPEG_NoBaselineJPEG "'Baseline JPEG' deaktiverat."

// vo_pnm.c

#define MSGTR_VO_PNM_ASCIIMode "ASCII-mode aktiverat."
#define MSGTR_VO_PNM_RawMode "Rtt-mode aktiverat." // FIXME Rtt sounds strange
#define MSGTR_VO_PNM_PPMType "Kommer att skriva PPM-filer."
#define MSGTR_VO_PNM_PGMType "Kommer att skriva PGM-filer."
#define MSGTR_VO_PNM_PGMYUVType "Kommer att skriva PGMYUV-filer."

// vo_yuv4mpeg.c

#define MSGTR_VO_YUV4MPEG_InterlacedHeightDivisibleBy4 "'Interlaced'-mode krver bildhjd som r delbar med 4." // FIXME interlaced?
#define MSGTR_VO_YUV4MPEG_InterlacedLineBufAllocFail "Ofrmgen att allokera linjebufferrt fr interlaced-mode."
#define MSGTR_VO_YUV4MPEG_InterlacedInputNotRGB "indata r ej i RGB-format, kan inte separera 'chrominance' via flt!" // FIXME chrominance
#define MSGTR_VO_YUV4MPEG_WidthDivisibleBy2 "Bildbredd mste vara delbart med 2."
#define MSGTR_VO_YUV4MPEG_NoMemRGBFrameBuf "Ej tillrckligt med minne fr att allokera RGB-bildramsbuffert."
#define MSGTR_VO_YUV4MPEG_OutFileOpenError "Kan inte f minnes- eller filhanterare att skriva till \"stream.yuv\"!"
#define MSGTR_VO_YUV4MPEG_OutFileWriteError "Fel vid skrivning av bild till ut!" // FIXME output here?
#define MSGTR_VO_YUV4MPEG_UnknownSubDev "Oknd subdevice: %s" // FIXME subdevice
#define MSGTR_VO_YUV4MPEG_InterlacedTFFMode "Anvnder 'interlaced output mode', vre fltet frst." // FIXME top-field first? && 'interlaced output mode'
#define MSGTR_VO_YUV4MPEG_InterlacedBFFMode "Anvnder 'interlaced output mode',nedre fltet frst." // FIXME bottom-field first? && 'interlaced output mode'

#define MSGTR_VO_YUV4MPEG_ProgressiveMode "Anvnder (som standard) progressiv bildramsinstllning."

// Old vo drivers that have been replaced

#define MSGTR_VO_PGM_HasBeenReplaced "pgm-video-ut-drivrutinen har blivit utbytt av '-vo pnm:pgmyuv'.\n"
#define MSGTR_VO_MD5_HasBeenReplaced "md5-video-ut-drivrutinen har blivit utbytt av '-vo md5sum'.\n"


// ======================= AO Audio Output drivers ========================

// libao2 

// audio_out.c

#define MSGTR_AO_ALSA9_1x_Removed "audio_out: alsa9- samt alsa1xmodulerna har blivit borttagna, anvnd -ao istllet.\n"

// ao_oss.c

#define MSGTR_AO_OSS_CantOpenMixer "[AO OSS] audio_setup: Kan inte ppna mixernehet %s: %s\n"
#define MSGTR_AO_OSS_ChanNotFound "[AO OSS] audio_setup: Audiokortsmixer har inte kanal '%s' anvnder standard.\n"
#define MSGTR_AO_OSS_CantOpenDev "[AO OSS] audio_setup: Kan inte ppna audioenhet %s: %s\n"
#define MSGTR_AO_OSS_CantMakeFd "[AO OSS] audio_setup: Kan inte f till 'filedescriptor'sblockning: %s\n" // FIXME filedescriptor
#define MSGTR_AO_OSS_CantSetAC3 "[AO OSS] Kan inte stta audioenhet %s till AC3-ut, prvar S16...\n"
#define MSGTR_AO_OSS_CantSetChans "[AO OSS] audio_setup: Misslyckades att stta audioenhet till %d kanaler.\n"
#define MSGTR_AO_OSS_CantUseGetospace "[AO OSS] audio_setup: dirvrutin hanerar ej SNDCTL_DSP_GETOSPACE :-(\n"
#define MSGTR_AO_OSS_CantUseSelect "[AO OSS]\n   ***  Din audiodrivrutin hanterar inte select()  ***\n Komplilera om med '#undef HAVE_AUDIO_SELECT' i config.h !\n\n" // TODO shoud be a better way to do this
#define MSGTR_AO_OSS_CantReopen "[AO OSS]\nFatalt fel: *** CAN INTE BLI TERPPNAD / TERSTLLER AUDIOENHET *** %s\n"

// ao_arts.c

#define MSGTR_AO_ARTS_CantInit "[AO ARTS] %s\n" // FIXME nothing?
#define MSGTR_AO_ARTS_ServerConnect "[AO ARTS] Anslutet till ljudserver.\n"
#define MSGTR_AO_ARTS_CantOpenStream "[AO ARTS] Ofrmgen att ppna en strm.\n" // FIXME 'strm' or 'ljudstrm'?
#define MSGTR_AO_ARTS_StreamOpen "[AO ARTS] Strm ppnad.\n" // -''-
#define MSGTR_AO_ARTS_BufferSize "[AO ARTS] buffertstorlek: %d\n"

// ao_dxr2.c

#define MSGTR_AO_DXR2_SetVolFailed "[AO DXR2] Sttning av volym till %d misslyckades.\n"
#define MSGTR_AO_DXR2_UnsupSamplerate "[AO DXR2] dxr2: %d Hz r ej tillgnglig, frsk med \"-aop list=resample\"\n"

// ao_esd.c

#define MSGTR_AO_ESD_CantOpenSound "[AO ESD] esd_open_sound misslyckades: %s\n"
#define MSGTR_AO_ESD_LatencyInfo "[AO ESD] latency: [server: %0.2fs, net: %0.2fs] (adjust %0.2fs)\n" // FIXME translate?
#define MSGTR_AO_ESD_CantOpenPBStream "[AO ESD] misslyckades att ppna uppspelningsstrm: %s\n" 

// ao_mpegpes.c

#define MSGTR_AO_MPEGPES_CantSetMixer "[AO MPEGPES] DVB-audio-sttningsmixer misslyckades: %s\n" // set ~= sttning?
#define MSGTR_AO_MPEGPES_UnsupSamplerate "[AO MPEGPES] %d Hz ej tillgnglig, frsker resampla...\n"

// ao_null.c
// This one desn't even have any mp_msg nor printf's?? [CHECK]

// ao_pcm.c

#define MSGTR_AO_PCM_FileInfo "[AO PCM] Fil: %s (%s)\nPCM: Samplerate: %iHz Kanaler: %s Format %s\n" // FIXME Samplerate?
#define MSGTR_AO_PCM_HintInfo "[AO PCM] Info: snabbaste dumplning r tillgnglig via -vc dummy -vo null\nPCM: Info: fr att skriva WAVE-filer anvnd -ao pcm:waveheader (standard).\n"
#define MSGTR_AO_PCM_CantOpenOutputFile "[AO PCM] Misslyckades att ppna %s fr skrivning!\n"

// ao_sdl.c

#define MSGTR_AO_SDL_INFO "[AO SDL] Samplerate: %iHz Kanaler: %s Format %s\n" // -''-
#define MSGTR_AO_SDL_DriverInfo "[AO SDL] anvnder %s som audioenhet.\n"
#define MSGTR_AO_SDL_UnsupportedAudioFmt "[AO SDL] Icke tillgngligt audioformat: 0x%x.\n" // support?
#define MSGTR_AO_SDL_CantInit "[AO SDL] Initialisering av 'SDL Audio' misslyckades: %s\n"
#define MSGTR_AO_SDL_CantOpenAudio "[AO SDL] Ofrmgen att ppna audio: %s\n" // audio what?

// ao_sgi.c

#define MSGTR_AO_SGI_INFO "[AO SGI] kontroll.\n"
#define MSGTR_AO_SGI_InitInfo "[AO SGI] init: Samplerate: %iHz Kanaler: %s Format %s\n" // FIXME Samplerate
#define MSGTR_AO_SGI_InvalidDevice "[AO SGI] play: icke godknd enhet.\n"
#define MSGTR_AO_SGI_CantSetParms_Samplerate "[AO SGI] init: setparams misslyckades: %s\nKunde inte stta nskad samplerate.\n" // -''-
#define MSGTR_AO_SGI_CantSetAlRate "[AO SGI] init: AL_RATE var inte accepterad p given resurs.\n"
#define MSGTR_AO_SGI_CantGetParms "[AO SGI] init: getparams misslyckades: %s\n"
#define MSGTR_AO_SGI_SampleRateInfo "[AO SGI] init: samplerate r nu %lf (nskad rate var %lf)\n" // -''- also rate?
#define MSGTR_AO_SGI_InitConfigError "[AO SGI] init: %s\n"
#define MSGTR_AO_SGI_InitOpenAudioFailed "[AO SGI] init: Ofrmgen att ppna audiokanal: %s\n"
#define MSGTR_AO_SGI_Uninit "[AO SGI] uninit: ...\n" // FIXME translate?
#define MSGTR_AO_SGI_Reset "[AO SGI] reset: ...\n" // -''-
#define MSGTR_AO_SGI_PauseInfo "[AO SGI] audio_pause: ...\n" // -''-
#define MSGTR_AO_SGI_ResumeInfo "[AO SGI] audio_resume: ...\n" // -''-

// ao_sun.c

#define MSGTR_AO_SUN_RtscSetinfoFailed "[AO SUN] rtsc: SETINFO misslyckades.\n"
#define MSGTR_AO_SUN_RtscWriteFailed "[AO SUN] rtsc: skrivning misslyckades."
#define MSGTR_AO_SUN_CantOpenAudioDev "[AO SUN] Kan inte ppna audioenhet %s, %s  -> inget ljud.\n"
#define MSGTR_AO_SUN_UnsupSampleRate "[AO SUN] audio_setup: ditt kort hanterar inte %d kanaler, %s, %d Hz samplerate.\n" // FIXME samplerate
#define MSGTR_AO_SUN_CantUseSelect "[AO SUN]\n   ***  Din ljudkortsenhet hanterar inte select()  ***\nKompilera om med '#undef HAVE_AUDIO_SELECT' i config.h !\n\n" // same as for MSGTR_AO_OSS_CantUseSelect
#define MSGTR_AO_SUN_CantReopenReset "[AO SUN]\nFatalt fel: *** KAN INTE TERPPNA / TERSTLLA AUDIOENHET (%s) ***\n"

// ao_alsa5.c

#define MSGTR_AO_ALSA5_InitInfo "[AO ALSA5] alsa-init: nskat format: %d Hz, %d kanaler, %s\n"
#define MSGTR_AO_ALSA5_SoundCardNotFound "[AO ALSA5] alsa-init: inga ljudkort funna.\n"
#define MSGTR_AO_ALSA5_InvalidFormatReq "[AO ALSA5] alsa-init: icke godknt format (%s) nskat - ut deaktiverat.\n" // FIXME output -> ut here?
#define MSGTR_AO_ALSA5_PlayBackError "[AO ALSA5] alsa-init: uppspelningsppningsfel: %s\n" 
#define MSGTR_AO_ALSA5_PcmInfoError "[AO ALSA5] alsa-init: pcm-infofel: %s\n"
#define MSGTR_AO_ALSA5_SoundcardsFound "[AO ALSA5] alsa-init: %d ljurtkort funna, anvnder: %s\n"
#define MSGTR_AO_ALSA5_PcmChanInfoError "[AO ALSA5] alsa-init: pcm-kanalinfofel: %s\n"
#define MSGTR_AO_ALSA5_CantSetParms "[AO ALSA5] alsa-init: fel vid sttning av parametrarna: %s\n" // FIXME setting?
#define MSGTR_AO_ALSA5_CantSetChan "[AO ALSA5] alsa-init: fel vid initiering av kanal: %s\n"
#define MSGTR_AO_ALSA5_ChanPrepareError "[AO ALSA5] alsa-init: kanalprepareringsfel: %s\n"
#define MSGTR_AO_ALSA5_DrainError "[AO ALSA5] alsa-uninit: uppspelningslnsningsfel: %s\n" // FIXME drain -> lnsning?
#define MSGTR_AO_ALSA5_FlushError "[AO ALSA5] alsa-uninit: uppspelningsspolningsfel: %s\n" // FIXME flush -> spolning?
#define MSGTR_AO_ALSA5_PcmCloseError "[AO ALSA5] alsa-uninit: pcm-stngningsfel: %s\n"
#define MSGTR_AO_ALSA5_ResetDrainError "[AO ALSA5] alsa-reset: uppspelningslnsningsfel: %s\n"
#define MSGTR_AO_ALSA5_ResetFlushError "[AO ALSA5] alsa-reset: uppspelningsspolningsfel: %s\n"
#define MSGTR_AO_ALSA5_ResetChanPrepareError "[AO ALSA5] alsa-reset: kanalprepareringsfel: %s\n"
#define MSGTR_AO_ALSA5_PauseDrainError "[AO ALSA5] alsa-pause: uppspelningslnsningsfel: %s\n"
#define MSGTR_AO_ALSA5_PauseFlushError "[AO ALSA5] alsa-pause: uppspelningsspolningsfel: %s\n"
#define MSGTR_AO_ALSA5_ResumePrepareError "[AO ALSA5] alsa-resume: kanalprepareringsfel: %s\n"
#define MSGTR_AO_ALSA5_Underrun "[AO ALSA5] alsa-play: alsa underrun, terstller strm.\n" // FIXME underun - translate?
#define MSGTR_AO_ALSA5_PlaybackPrepareError "[AO ALSA5] alsa-play: uppspelningsprepareringsfel: %s\n"
#define MSGTR_AO_ALSA5_WriteErrorAfterReset "[AO ALSA5] alsa-play: skrivfel efter terstllning: %s - ger upp.\n"
#define MSGTR_AO_ALSA5_OutPutError "[AO ALSA5] alsa-play: utfel: %s\n" // FIXME output -> ut her?

// ao_plugin.c

#define MSGTR_AO_PLUGIN_InvalidPlugin "[AO PLUGIN] icke godknd plugin: %s\n" // FIXME plugin - translate?

